==> maverick-virtual-session-3.0.10-sources.jar: com/sshtools/server/vsession/commands/sftp/Lcd.java <==
/**
 * (c) 2002-2021 JADAPTIVE Limited. All Rights Reserved.
 *
 * This file is part of the Maverick Synergy Java SSH API.
 *
 * Maverick Synergy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Maverick Synergy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Maverick Synergy.  If not, see <https://www.gnu.org/licenses/>.
 */
package com.sshtools.server.vsession.commands.sftp;

import java.io.IOException;

import com.sshtools.common.permissions.PermissionDeniedException;
import com.sshtools.common.sftp.SftpStatusException;
import com.sshtools.server.vsession.Environment;
import com.sshtools.server.vsession.UsageException;
import com.sshtools.server.vsession.VirtualConsole;

public class Lcd extends SftpCommand {

	public Lcd() {
		super("lcd", "SFTP", "lcd", "Moves the working directory to a new directory");
	}

	@Override
	public void run(String[] args, VirtualConsole console)
			throws IOException, PermissionDeniedException, UsageException {

		if (args.length > 2)
			throw new IllegalArgumentException("Too many arguments.");
		if (args.length > 1) {
			cdLocal(args[1]);
		} else {
			cdLocal((String) console.getEnvironment().getOrDefault(Environment.ENV_HOME, ""));
		}
	}


	private void cdLocal(String directory) {
		try {
			this.sftp.lcd(directory);
		} catch (IOException | PermissionDeniedException | SftpStatusException e) {
			throw new IllegalStateException(e.getMessage(), e);
		}
	}
	
}

==> maverick-virtual-session-3.1.2-sources.jar: com/sshtools/server/vsession/commands/sftp/Lcd.java <==
package com.sshtools.server.vsession.commands.sftp;

/*-
 * #%L
 * Virtual Sessions
 * %%
 * Copyright (C) 2002 - 2024 JADAPTIVE Limited
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

import java.io.IOException;

import com.sshtools.common.permissions.PermissionDeniedException;
import com.sshtools.common.sftp.SftpStatusException;
import com.sshtools.server.vsession.Environment;
import com.sshtools.server.vsession.UsageException;
import com.sshtools.server.vsession.VirtualConsole;

public class Lcd extends SftpCommand {

	public Lcd() {
		super("lcd", "SFTP", "lcd", "Moves the working directory to a new directory");
	}

	@Override
	public void run(String[] args, VirtualConsole console)
			throws IOException, PermissionDeniedException, UsageException {

		if (args.length > 2)
			throw new IllegalArgumentException("Too many arguments.");
		if (args.length > 1) {
			cdLocal(args[1]);
		} else {
			cdLocal((String) console.getEnvironment().getOrDefault(Environment.ENV_HOME, ""));
		}
	}


	private void cdLocal(String directory) {
		try {
			this.sftp.lcd(directory);
		} catch (IOException | PermissionDeniedException | SftpStatusException e) {
			throw new IllegalStateException(e.getMessage(), e);
		}
	}
	
}
